@@ -7,11 +7,13 @@
 #ifndef PLASMA_NM_WIREGUARD_TAB_WIDGET_H
 #define PLASMA_NM_WIREGUARD_TAB_WIDGET_H
 
+#include "plasmanm_editor_export.h"
+
 #include <QDialog>
 
 #include <NetworkManagerQt/WireguardSetting>
 
-class Q_DECL_EXPORT WireGuardTabWidget : public QDialog
+class PLASMANM_EDITOR_EXPORT WireGuardTabWidget : public QDialog
 {
     Q_OBJECT
 
