@@ -7,12 +7,17 @@
 #ifndef PLASMA_NM_KCM_IDENTITY_MODEL_H
 #define PLASMA_NM_KCM_IDENTITY_MODEL_H
 
+#include "plasmanm_internal_export.h"
+
 #include <QIdentityProxyModel>
 #include <QModelIndex>
 
-class Q_DECL_EXPORT KcmIdentityModel : public QIdentityProxyModel
+#include <qqmlregistration.h>
+
+class PLASMANM_INTERNAL_EXPORT KcmIdentityModel : public QIdentityProxyModel
 {
     Q_OBJECT
+    QML_ELEMENT
 public:
     explicit KcmIdentityModel(QObject *parent = nullptr);
     ~KcmIdentityModel() override;
